==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebColumnMovingStartEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnMovingStartEventArgsDetailDescriptionMetadata } from "./WebColumnMovingStartEventArgsDetailDescriptionMetadata";
import { WebColumnMovingStartEventArgsDescription } from "./WebColumnMovingStartEventArgsDescription";
/**
 * @hidden
 */
var WebColumnMovingStartEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnMovingStartEventArgsDescriptionMetadata, _super);
    function WebColumnMovingStartEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnMovingStartEventArgsDescriptionMetadata.b = function (a) {
        if (WebColumnMovingStartEventArgsDescriptionMetadata.a == null) {
            WebColumnMovingStartEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnMovingStartEventArgsDescriptionMetadata.c(WebColumnMovingStartEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebColumnMovingStartEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebColumnMovingStartEventArgsDescriptionMetadata.a);
        WebColumnMovingStartEventArgsDetailDescriptionMetadata.d(a);
    };
    WebColumnMovingStartEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnMovingStartEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebColumnMovingStartEventArgsDetail");
    };
    WebColumnMovingStartEventArgsDescriptionMetadata.d = function (a) {
        WebColumnMovingStartEventArgsDescriptionMetadata.b(a);
        a.aa("WebColumnMovingStartEventArgs", function () { return new WebColumnMovingStartEventArgsDescription(); });
        a.z("WebColumnMovingStartEventArgs", WebColumnMovingStartEventArgsDescriptionMetadata.a);
    };
    WebColumnMovingStartEventArgsDescriptionMetadata.$t = markType(WebColumnMovingStartEventArgsDescriptionMetadata, 'WebColumnMovingStartEventArgsDescriptionMetadata');
    WebColumnMovingStartEventArgsDescriptionMetadata.a = null;
    return WebColumnMovingStartEventArgsDescriptionMetadata;
}(Base));
export { WebColumnMovingStartEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebColumnMovingStartEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnMovingStartEventArgsDetailDescriptionMetadata } from "./WebColumnMovingStartEventArgsDetailDescriptionMetadata";
import { WebColumnMovingStartEventArgsDescription } from "./WebColumnMovingStartEventArgsDescription";
/**
 * @hidden
 */
var WebColumnMovingStartEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnMovingStartEventArgsDescriptionMetadata, _super);
    function WebColumnMovingStartEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnMovingStartEventArgsDescriptionMetadata.b = function (a) {
        if (WebColumnMovingStartEventArgsDescriptionMetadata.a == null) {
            WebColumnMovingStartEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnMovingStartEventArgsDescriptionMetadata.c(WebColumnMovingStartEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebColumnMovingStartEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebColumnMovingStartEventArgsDescriptionMetadata.a);
        WebColumnMovingStartEventArgsDetailDescriptionMetadata.d(a);
    };
    WebColumnMovingStartEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnMovingStartEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebColumnMovingStartEventArgsDetail");
    };
    WebColumnMovingStartEventArgsDescriptionMetadata.d = function (a) {
        WebColumnMovingStartEventArgsDescriptionMetadata.b(a);
        a.ac("WebColumnMovingStartEventArgs", function () { return new WebColumnMovingStartEventArgsDescription(); });
        a.ab("WebColumnMovingStartEventArgs", WebColumnMovingStartEventArgsDescriptionMetadata.a);
    };
    WebColumnMovingStartEventArgsDescriptionMetadata.$t = markType(WebColumnMovingStartEventArgsDescriptionMetadata, 'WebColumnMovingStartEventArgsDescriptionMetadata');
    WebColumnMovingStartEventArgsDescriptionMetadata.a = null;
    return WebColumnMovingStartEventArgsDescriptionMetadata;
}(Base));
export { WebColumnMovingStartEventArgsDescriptionMetadata };
